**1. ??requirement.txt**

pip freeze > requirement.txt

**2. ??**

****pip install --upgrade pip twine wheel setuptools

python setup.py sdist bdist_wheel

twine upload dist/* 

??twine upload --skip-existing dist/* ?????????

**3. ??????**

pip install --upgrade tsdl

**4. ????**

package_dir:
??Distutils???????????????????????package_dir = {'': 'lib'}????root package???????lib????